/* Copyright 2020 The TensorFlow Authors. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
==============================================================================*/
#ifndef TENSORFLOW_CORE_TPU_KERNELS_TRACE_UTIL_H_
#define TENSORFLOW_CORE_TPU_KERNELS_TRACE_UTIL_H_

#ifdef PLATFORM_GOOGLE
#include "base/tracer.h"  // IWYU pragma: export
#else
#undef TRACESTRING
#define TRACESTRING(x)
#undef TRACELITERAL
#define TRACELITERAL(x)
#endif

#endif  // TENSORFLOW_CORE_TPU_KERNELS_TRACE_UTIL_H_
